function x = XjSec(z,l,w)
% Yields Xj(z,w) the mistuned response of 
% ALL BLADES due to the jth mode/eigenvalue:
% correct up to first order in eigenvectors 
% and second order in eigenvalues.
%
% As in EigenSec.m, do not use symbolic z's,
% Matlab cannot handle r^2 symbolic variables. 

clear i;
  global Psi0;
  global DPsi;
  global EigenTun;
  global a;
  global b;
  global c;
  global d;
  global r;

tic
% Initialize
  x = zeros(r*d,1);    % resp. for all blades.
  Psiz = zeros(r*d,1); % Psi(z) for all blades.
  delta_Eig = EigenSec(z,a,b,c,r); % 2nd order change in eigenvals by mist.


% Sum over all modes.
  for j = 1:r*d
    % Cycle through all blades for Psi(z)
      for q=0:r-1
        Psiz(q*d+1:(q+1)*d) = p(l*q,r)*( Psi0(:,j) + DPsi(:,:,j)*rot(z,q,1,r)' ); 
      end
    % Got Psi(z) for all blades.
  
    % Now compute: X(z,w) = Psi(z)/(iw-lambda(z)).
      x = x + Psiz/(i*w -EigenTun(j) -delta_Eig(j) );
    % Got X(z,w)
  end
% Got all modes.
toc





% On: 04/28/98
% Very slow right now! How to speed this up ?
% I have two loops in here. Need to figure out
% how to do this in matrix format ? Right now
% the pass takes about 2 seconds and the 
% computation about 14 seconds: total 16 sec.

% On: 04/29/98
% By making variables global I have speeded it up
% by 11 seconds (down to 5 seconds). The next 
% thing to do is take out the q loop.

% B. Shapiro, Caltech, 04/28/98.
