% Matlab Mistuning Code: Version 2.0
%
% Created by: Benjamin Shapiro,
%             Control and Dynamical Systems
%             California Institute of Technology
%             Pasadena, CA 91125.
%             bshapiro@indra.caltech.edu
%
%   Copyright (c) 1998, California Institute of Technology.
%   Permission is granted to copy, modify, and redistribute
%   this software provided all header messages are retained.
%
% *********************************************************
%
% File: conv_sinha.m
% Purpose: Check at what size mistuning Sinha's series
%   method fails to converge.
% Last Update: 06/12/98 by B.Shapiro
%
% *********************************************************

clear;

% Load saved data:
  load('Data/modelvar');
  load('Outputs/TunEig');
  load('Outputs/forced');
  load('Outputs/PertEig');
% End load.


% Pick freq.
  w = 1.0;
% Got freq.

% Pick random mistuning of size 1.
  randn('state',sum(100*clock)); % new seed.
  Y = randn(1,r);                % mistuning: |Y| = 1.
% Got mistuning.



% First get M(0).
     M0 = zeros(r*d); 
     % Construct M(0)
     for j = 0:r-1
       M0(j*d+1:(j+1)*d,:) = rot( MrowTun, r-j, d, r); % Tuned part.
     end
% Got M(0)



% Now define A(0)
  A0 = i*w*eye(r*d) - M0;
% Got A(0)



inc = 0.002;
steps = 10;


for k = 1:steps
  % Define scaled mistuning:
    sz = inc*k;
    y = sz*Y;



  % Now define dAz = dMz (here: z=y).
    % Code below is PW model specific!
      zeta = 0.00032;
      for j = 0:r-1
        dMy(j*d+1:(j+1)*d,:) = zeros(d,r*d); % Tuned part.
          % Now modify by mistuning: elements (2,1) and (2,2).
            dMy((j+1)*d,j*d+1) = -2*y(j+1) -y(j+1)^2;
            dMy((j+1)*d,j*d+2) = -2*zeta*y(j+1);
      end
  % Got dMz.


  % Compute Inv[A0].dAy and check spectral radius
    P = inv(A0)*dMy;
    x = eig(P);
    specrad(k) = max( abs(x) ); 
  % Got specrad
end



% Plot results
  clf;
  Sz = (0:steps)*inc;
  plot(Sz,[0 specrad],'r-');
  line( [0 steps*inc], [1 1]);
  title('Series Method Convergence');
  xlabel('random mistuning size');
  ylabel('spectral radius of Inv[A0].dAz');
  axis([0 steps*inc 0 max(specrad)]);  
  addinfo('', date, 'Method converges if and only if spectral radius less than one', ...
          'MAST: B. Shapiro, Caltech');
% End plot


% Comment: Sinha's method fails to converge at (roughly)
%   1% mistuning size for the PW model. (Here 1% means
%   the size of the variance in a Gaussian distrubtion. So
%   if I am a little bit more charitable and take ||y||_inf
%   as my measure this corresponds to failure at 2%. 05/11/98.)

% Print plot to file:
  print -depsc Outputs/conv_sinha.eps
