function x = eig2(A)
% Compute analytically eigenvalue/vectors of 2 by 2 matrix.
%
%   Copyright (c) 1998, California Institute of Technology.
%   Permission is granted to copy, modify, and redistribute
%   this software provided all header messages are retained.


a = A(1,1);
b = A(1,2);
c = A(2,1);
d = A(2,2);

delta = sqrt(a^2 +4*b*c -2*a*d +d^2 );



% Eigenvalues:
eigenvals = 0.5 * [ a+d-delta ;
                    a+d+delta ];
                    
% Right (v) and Left (u) eigenvectors:
if c & b   % for nonzero b and c.
  v1 = [ (a-d-delta)/(2*c); 1];
  v2 = [ (a-d+delta)/(2*c); 1];
  u1 = [ (a-d-delta)/(2*b), 1];
  u2 = [ (a-d+delta)/(2*b), 1];
elseif b   % nonzero b, zero c.
  v1 = [ 1; 0];
  v2 = [ b/(d-a); 1];
  u1 = [ (a-d)/b, 1];
  u2 = [ 0, 1];
  if a==d
     fprintf('WARNING: NON-DISTINCT EIGENVALUES, METHOD FAILS!!! \n')
  end
elseif c   % nonzero c, zero b.
  v1 = [ (a-d)/c; 1];
  v2 = [ 0; 1];
  u1 = [ 1, 0];
  u2 = [ c/(d-a), 1];
  if a==d
     fprintf('WARNING: NON-DISTINCT EIGENVALUES, METHOD FAILS!!! \n')
  end
end

% Normalize right eigenvectors: ||vj|| = 1.
  v1 = v1/norm(v1);
  v2 = v2/norm(v2);
  V = [v1, v2];

% Normalize left eigenvectors: ui.vj = delta_ij
  u1 = u1/(u1*v1);
  u2 = u2/(u2*v2);
  U = [ u1; u2];
  % Note: UV = VU = I.




% Compose output of eigenvalues and eigenvectors:
   x = [eigenvals, V, U ];
% given the matrix A in closed form.

% Output: 2 eigenvalues (1rst column)
%         2 right (column) eigenvectors (2rd & 3rd columns)
%         2 left (row) eigenvectors (4th & 5th columns).


% Computes eigenvalues and left,right eigenvectors
% for 2 by 2 complex matrices. I do this because the
% above analytic formulas are faster and more accurate
% then the Matlab numerical solution techniques. In
% principle, the above can be extended up to d = 5.
% Theoretically, it is not possible to find closed form
% roots for polynomials of order 6 or greater.

% B. Shapiro, Caltech, 03/31/98.
