% Matlab Mistuning Code: Version 2.0
%
% Created by: Benjamin Shapiro,
%             Control and Dynamical Systems
%             California Institute of Technology
%             Pasadena, CA 91125.
%             bshapiro@indra.caltech.edu
%
%   Copyright (c) 1998, California Institute of Technology.
%   Permission is granted to copy, modify, and redistribute
%   this software provided all header messages are retained.
%
% *********************************************************
%
% File: modal_input.m
% Purpose: Compute nodal content of any given vector.
% Last Update: 06/12/98 by B.Shapiro
%
% *********************************************************

r = 40;

% Example:
  % F = p(127,r).^(0:1:r-1); % row forcing vector
  F = randn(1,r);


    % Note: F must be row vector.
    decomp = zeros(r,1);
    for j = 1:r
      decomp(j) =   abs( ( p(-j,r).^(0:1:r-1) )*F.' );
      % Basically computing: aj = |<F,Pj>| = |F.Conj[Pj]|,
      % the inner-product gives modal content aj. I do -j
      % in the p(-j) to get the Conj[Pj]. X0.' is so that
      % it takes regular dot product---not the conjugate.
    end

    figure(1);
    clf;
    bar(decomp,'r')
    title('Modal Decomposition');
    xlabel('nodal diameter');
    ylabel('modal content');
    xmin = 0;
    xmax = r+1;
    ymin = 0;
    ymax = 1.05 * max( decomp );  
    axis([xmin xmax ymin ymax]);
    addinfo('', date, '', 'MAST: B. Shapiro, Caltech');
 
